@@ -34,7 +34,7 @@
 #' # Apply the function to all vl columns using purrr's map_dfc
 #' library(viraldomain)
 #' data("viral", package = "viraldomain")
-#' viral_imputed <- viral |>
+#' viral_imputed <- viral %>%
 #' mutate(across(starts_with("vl"), ~impute_undetectable(.x)))
 #' traindata <- viral_imputed
 #' semilla <- 1501
@@ -51,55 +51,55 @@ viralvis <- function(traindata, semilla, target, viralvars, logbase, pliegues, r
   dplyr::bind_rows(
     workflowsets::workflow_set(
       preproc = list(simple = workflows::workflow_variables(outcomes = tidyselect::all_of(target), predictors = tidyselect::everything())),
-      models = list(rf = parsnip::rand_forest(mtry = hardhat::tune(), min_n = hardhat::tune(), trees = hardhat::tune()) |>
-                      parsnip::set_engine("ranger") |>
+      models = list(rf = parsnip::rand_forest(mtry = hardhat::tune(), min_n = hardhat::tune(), trees = hardhat::tune()) %>%
+                      parsnip::set_engine("ranger") %>%
                       parsnip::set_mode("regression"),
-                    CART_bagged = parsnip::bag_tree() |>
-                      parsnip::set_engine("rpart", times = 50L) |>
+                    CART_bagged = parsnip::bag_tree() %>%
+                      parsnip::set_engine("rpart", times = 50L) %>%
                       parsnip::set_mode("regression"),
-                    Cubist = parsnip::cubist_rules(committees = hardhat::tune(), neighbors = hardhat::tune()) |>
+                    Cubist = parsnip::cubist_rules(committees = hardhat::tune(), neighbors = hardhat::tune()) %>%
                       parsnip::set_engine("Cubist")
       )
     ),
     workflowsets::workflow_set(
-      preproc = list(normalized = recipes::recipe(stats::as.formula(paste(target, "~ .")), data = traindata) |>
-                       recipes::step_log(tidyselect::all_of(viralvars), base = logbase) |>
+      preproc = list(normalized = recipes::recipe(stats::as.formula(paste(target, "~ .")), data = traindata) %>%
+                       recipes::step_log(tidyselect::all_of(viralvars), base = logbase) %>%
                        recipes::step_normalize(recipes::all_predictors())),
-      models = list(SVM_radial = parsnip::svm_rbf(cost = hardhat::tune(), rbf_sigma = hardhat::tune()) |>
-                      parsnip::set_engine("kernlab") |>
+      models = list(SVM_radial = parsnip::svm_rbf(cost = hardhat::tune(), rbf_sigma = hardhat::tune()) %>%
+                      parsnip::set_engine("kernlab") %>%
                       parsnip::set_mode("regression"),
-                    SVM_poly = parsnip::svm_poly(cost = hardhat::tune(), degree = hardhat::tune()) |>
-                      parsnip::set_engine("kernlab") |>
+                    SVM_poly = parsnip::svm_poly(cost = hardhat::tune(), degree = hardhat::tune()) %>%
+                      parsnip::set_engine("kernlab") %>%
                       parsnip::set_mode("regression"),
-                    KNN = parsnip::nearest_neighbor(neighbors = hardhat::tune(), dist_power = hardhat::tune(), weight_func = hardhat::tune()) |>
-                      parsnip::set_engine("kknn") |>
+                    KNN = parsnip::nearest_neighbor(neighbors = hardhat::tune(), dist_power = hardhat::tune(), weight_func = hardhat::tune()) %>%
+                      parsnip::set_engine("kknn") %>%
                       parsnip::set_mode("regression"),
-                    neural_network = parsnip::mlp(hidden_units = hardhat::tune(), penalty = hardhat::tune(), epochs = hardhat::tune()) |>
-                      parsnip::set_engine("nnet", MaxNWts = 2600) |>
+                    neural_network = parsnip::mlp(hidden_units = hardhat::tune(), penalty = hardhat::tune(), epochs = hardhat::tune()) %>%
+                      parsnip::set_engine("nnet", MaxNWts = 2600) %>%
                       parsnip::set_mode("regression")
       )
-    ) |>
-      workflowsets::option_add(param_info = parsnip::mlp(hidden_units = hardhat::tune(), penalty = hardhat::tune(), epochs = hardhat::tune()) |>
-                                 parsnip::set_engine("nnet", MaxNWts = 2600) |>
-                                 parsnip::set_mode("regression") |>
-                                 tune::extract_parameter_set_dials() |>
+    ) %>%
+      workflowsets::option_add(param_info = parsnip::mlp(hidden_units = hardhat::tune(), penalty = hardhat::tune(), epochs = hardhat::tune()) %>%
+                                 parsnip::set_engine("nnet", MaxNWts = 2600) %>%
+                                 parsnip::set_mode("regression") %>%
+                                 tune::extract_parameter_set_dials() %>%
                                  recipes::update(hidden_units = dials::hidden_units(c(1, 27))),
                                id = "normalized_neural_network"),
     workflowsets::workflow_set(
-      preproc = list(full_quad = recipes::recipe(stats::as.formula(paste(target, "~ .")), data = traindata) |>
-                       recipes::step_log(tidyselect::all_of(viralvars), base = logbase) |>
-                       recipes::step_normalize(recipes::all_predictors())  |>
-                       recipes::step_poly(recipes::all_predictors()) |>
+      preproc = list(full_quad = recipes::recipe(stats::as.formula(paste(target, "~ .")), data = traindata) %>%
+                       recipes::step_log(tidyselect::all_of(viralvars), base = logbase) %>%
+                       recipes::step_normalize(recipes::all_predictors())  %>%
+                       recipes::step_poly(recipes::all_predictors()) %>%
                        recipes::step_interact(~ recipes::all_predictors():recipes::all_predictors())
       ),
-      models = list(linear_reg = parsnip::linear_reg(penalty = hardhat::tune(), mixture = hardhat::tune()) |>
+      models = list(linear_reg = parsnip::linear_reg(penalty = hardhat::tune(), mixture = hardhat::tune()) %>%
                       parsnip::set_engine("glmnet"),
-                    KNN = parsnip::nearest_neighbor(neighbors = hardhat::tune(), dist_power = hardhat::tune(), weight_func = hardhat::tune()) |>
-                      parsnip::set_engine("kknn") |>
+                    KNN = parsnip::nearest_neighbor(neighbors = hardhat::tune(), dist_power = hardhat::tune(), weight_func = hardhat::tune()) %>%
+                      parsnip::set_engine("kknn") %>%
                       parsnip::set_mode("regression")
       )
     )
-  ) |>
+  ) %>%
     workflowsets::workflow_map(
       seed = semilla,
       resamples = rsample::vfold_cv(traindata, v = pliegues, repeats = repeticiones),
@@ -109,7 +109,7 @@ viralvis <- function(traindata, semilla, target, viralvars, logbase, pliegues, r
         parallel_over = "everything",
         save_workflow = TRUE
       )
-    ) |>
+    ) %>%
     tune::autoplot(
       rank_metric = "rmse",  # <- how to order models
       metric = "rmse",       # <- which metric to visualize
