@@ -16,7 +16,7 @@ test_that("viraltab() works", {
   # Apply the function to all vl columns using purrr's map_dfc
   library(viraldomain)
   data("viral", package = "viraldomain")
-  viral_imputed <- viral |>
+  viral_imputed <- viral %>%
     mutate(across(starts_with("vl"), ~impute_undetectable(.x)))
   traindata <- viral_imputed
   semilla <- 123
@@ -26,6 +26,6 @@ test_that("viraltab() works", {
   pliegues <- 2
   repeticiones <- 1
   rejilla <- 1
-  expect_snapshot(print(viraltab(traindata, semilla, target, viralvars, logbase, pliegues, repeticiones, rejilla)))
+  expect_snapshot(print(viraltab(traindata, semilla, target, viralvars, logbase, pliegues, repeticiones, rejilla, rank_output = TRUE)))
 })
 
